@@ -114,6 +114,7 @@ case "con i costi aggiuntivi selezionati":  	$messaggio = "med valda extrakostna
 case "I beni richiesti dal costo":  		$messaggio = "Varor som beh&ouml;vs f&ouml;r kostnaden"; break;
 case "non sono disponibili nell'inventario":  	$messaggio = "&auml;r inte tillg&auml;ngliga i inventariet"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "Clienti":  				$messaggio = "Clients"; break;
 case "Piazzale":  				$messaggio = "Boulevard"; break;
 case "regione":  				$messaggio = "region"; break;
 case "reg./prov.":  				$messaggio = "region"; break;
@@ -127,6 +128,19 @@ case "lingua":  				$messaggio = "language"; break;
 case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
 case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
 case "Commento":  				$messaggio = "Comment"; break;
+case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
+case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
+case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
+case "E-mail":  				$messaggio = "E-mail"; break;
+case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
+case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
+case "Per questa tariffa si deve inserire un numero minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "persona":  				$messaggio = "person"; break;
+case "Usa il cliente della prenotazione originale":	$messaggio = "Use the client from the original reservation"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
