@@ -61,25 +61,6 @@ case " e vi erano":  				$messaggio = " och det finns"; break;
 case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservationer som slutar efter gr&auml;nserna som givits f&ouml;r  "; break;
 case ", queste prenotazioni non sono state importate":	$messaggio = ", dessa reservationer har inte importerats"; break;
 case "Anno già creato": 			$messaggio = "&Aring;ret har redan skapats"; break;
-case " Do":  					$messaggio = " S&ouml;"; break;
-case " Lu":  					$messaggio = " M&aring;"; break;
-case " Ma":  					$messaggio = " Ti"; break;
-case " Me":  					$messaggio = " On"; break;
-case " Gi":  					$messaggio = " To"; break;
-case " Ve":  					$messaggio = " Fr"; break;
-case " Sa":  					$messaggio = " L&ouml;"; break;
-case "Gen":  					$messaggio = "jan"; break;
-case "Feb":  					$messaggio = "feb"; break;
-case "Mar":  					$messaggio = "mar"; break;
-case "Apr":  					$messaggio = "apr"; break;
-case "Mag":  					$messaggio = "maj"; break;
-case "Giu":  					$messaggio = "jun"; break;
-case "Lug":  					$messaggio = "jul"; break;
-case "Ago":  					$messaggio = "aug"; break;
-case "Set":  					$messaggio = "sep"; break;
-case "Ott":  					$messaggio = "okt"; break;
-case "Nov":  					$messaggio = "nov"; break;
-case "Dic":  					$messaggio = "dec"; break;
 case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Formatet f&ouml;r det &ouml;nskade &aring;ret &auml;r fel"; break;
 case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "M&aring;naderna har valts felaktigt, de ska l&auml;ggas in fr&aring;n januari till december"; break;
 case "Cognome del cliente":  			$messaggio = "Kund efternamn"; break;
@@ -126,6 +107,13 @@ case "Avviso":  				$messaggio = "Warning"; break;
 case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
 case "mesi":  					$messaggio = "months"; break;
 case "OK, ho capito":  				$messaggio = "OK, got it"; break;
+case "Crea Anno":  				$messaggio = "Create Year"; break;
+case "Nota":  					$messaggio = "Notice"; break;
+case "l'anno":  				$messaggio = "year"; break;
+case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
+case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
+case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
+case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
