@@ -38,7 +38,8 @@ case "Nuovi messaggi":  			$messaggio = "New messages"; break;
 case "Scaricati":  				$messaggio = "Downloaded"; break;
 case "Connessione al server":  			$messaggio = "The connection to server"; break;
 case "non riuscita!":  				$messaggio = "was refused!"; break;
-case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Check data inserted in \"configure and customize\""; break;
+case "Controllare i dati immessi in":  		$messaggio = "Check data inserted in"; break;
+case "configura e personalizza":  		$messaggio = "configure and customize"; break;
 case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
 case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
 case "Modifica":  				$messaggio = "Modify"; break;
@@ -56,6 +57,8 @@ case "gruppo":  				$messaggio = "party"; break;
 case "date":  					$messaggio = "dates"; break;
 case "viaggiatori":  				$messaggio = "travelers"; break;
 case "periodo":  				$messaggio = "period"; break;
+case "Per gli account su gmail potrebbe essere necessario abilitare l'opzione":	$messaggio = "For gmail accounts you may have to enable the option"; break;
+case "e/o per una volta usare prima la funzione":	$messaggio = "and/or for once use beforehand the function"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
