@@ -202,6 +202,7 @@ case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun p
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Ta bort kunder utan reservationer"; break;
 case "Metodo pagamento":  			$messaggio = "Betalningsmetod"; break;
 case "Tariffe":  				$messaggio = "Priser"; break;
+case "del":  					$messaggio = "of"; break;
 case "Modifica tutti i campi della tabella":  	$messaggio = "&Auml;ndra alla tabellf&auml;lt"; break;
 case "Modifica i campi della tabella":  	$messaggio = "&Auml;ndra tabellf&auml;lt"; break;
 case "Applica i cambiamenti":  			$messaggio = "Till&auml;mpa &auml;ndringar"; break;
@@ -260,6 +261,8 @@ case "giorno":  				$messaggio = "day"; break;
 case "p":  					$messaggio = "p"; break;
 case "Aggiungi":  				$messaggio = "Add"; break;
 case "e":  					$messaggio = "and"; break;
+case "Id":  					$messaggio = "Id"; break;
+case "chiedere":  				$messaggio = "ask"; break;
 case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
 case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
 case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
@@ -267,6 +270,7 @@ case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
 case "Caparre, commissioni e tasse del":  	$messaggio = "Deposits, commissions and taxes of"; break;
 case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Table with the assignment rules"; break;
 case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
 case "cambia":  				$messaggio = "change"; break;
 case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
@@ -363,7 +367,6 @@ case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
 case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
 case "sono state convertite in":  		$messaggio = "have been converted into"; break;
 case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
-case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
 case "Attenzione":  				$messaggio = "Notice"; break;
 case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
@@ -371,11 +374,17 @@ case "come tipo di persona":  			$messaggio = "as person type"; break;
 case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
 case "escludendo":  				$messaggio = "excluding"; break;
 case "includendo solo":  			$messaggio = "including only"; break;
-case "Tabella con le regole di assegnazione":	$messaggio = "Table with the assignment rules"; break;
-case "del":  					$messaggio = "of"; break;
+case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
+case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
+case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
+case "Cancellare anche":  			$messaggio = "Delete also"; break;
+case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Anche cancellate":  			$messaggio = "Also deleted"; break;
+case "Solo cancellate":  			$messaggio = "Only deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
